from algora.common.base_enum import BaseEnum


class DatasetDataType(BaseEnum):
    STOCK = "STOCK"
